#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MINNUMMAG_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MINNUMMAG_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/minnummag.hpp>

#endif
